from coldtype.geometry.rect import Rect
from coldtype.text.reader import Style, StyledString, SegmentedString, normalize_font_path, Font, FontNotFoundException
from coldtype.text.composer import Slug, Lockup, Graf, GrafStyle, T2L, Composer, StSt, Glyphwise
#from coldtype.text.richtext import RichText